@@ -6,9 +6,9 @@ Type annotations for resource-groups service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_resource_groups.type_defs import CreateGroupOutputTypeDef
+    from mypy_boto3_resource_groups.type_defs import CreateGroupInputRequestTypeDef
 
-    data: CreateGroupOutputTypeDef = {...}
+    data: CreateGroupInputRequestTypeDef = {...}
     ```
 """
 import sys
@@ -32,12 +32,18 @@ else:
 
 
 __all__ = (
+    "CreateGroupInputRequestTypeDef",
     "CreateGroupOutputTypeDef",
+    "DeleteGroupInputRequestTypeDef",
     "DeleteGroupOutputTypeDef",
     "FailedResourceTypeDef",
+    "GetGroupConfigurationInputRequestTypeDef",
     "GetGroupConfigurationOutputTypeDef",
+    "GetGroupInputRequestTypeDef",
     "GetGroupOutputTypeDef",
+    "GetGroupQueryInputRequestTypeDef",
     "GetGroupQueryOutputTypeDef",
+    "GetTagsInputRequestTypeDef",
     "GetTagsOutputTypeDef",
     "GroupConfigurationItemTypeDef",
     "GroupConfigurationParameterTypeDef",
@@ -45,27 +51,61 @@ __all__ = (
     "GroupFilterTypeDef",
     "GroupIdentifierTypeDef",
     "GroupQueryTypeDef",
+    "GroupResourcesInputRequestTypeDef",
     "GroupResourcesOutputTypeDef",
     "GroupTypeDef",
+    "ListGroupResourcesInputRequestTypeDef",
     "ListGroupResourcesItemTypeDef",
     "ListGroupResourcesOutputTypeDef",
+    "ListGroupsInputRequestTypeDef",
     "ListGroupsOutputTypeDef",
     "PaginatorConfigTypeDef",
     "PendingResourceTypeDef",
+    "PutGroupConfigurationInputRequestTypeDef",
     "QueryErrorTypeDef",
     "ResourceFilterTypeDef",
     "ResourceIdentifierTypeDef",
     "ResourceQueryTypeDef",
     "ResourceStatusTypeDef",
     "ResponseMetadataTypeDef",
+    "SearchResourcesInputRequestTypeDef",
     "SearchResourcesOutputTypeDef",
+    "TagInputRequestTypeDef",
     "TagOutputTypeDef",
+    "UngroupResourcesInputRequestTypeDef",
     "UngroupResourcesOutputTypeDef",
+    "UntagInputRequestTypeDef",
     "UntagOutputTypeDef",
+    "UpdateGroupInputRequestTypeDef",
     "UpdateGroupOutputTypeDef",
+    "UpdateGroupQueryInputRequestTypeDef",
     "UpdateGroupQueryOutputTypeDef",
 )
 
+_RequiredCreateGroupInputRequestTypeDef = TypedDict(
+    "_RequiredCreateGroupInputRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalCreateGroupInputRequestTypeDef = TypedDict(
+    "_OptionalCreateGroupInputRequestTypeDef",
+    {
+        "Description": str,
+        "ResourceQuery": "ResourceQueryTypeDef",
+        "Tags": Dict[str, str],
+        "Configuration": List["GroupConfigurationItemTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateGroupInputRequestTypeDef(
+    _RequiredCreateGroupInputRequestTypeDef, _OptionalCreateGroupInputRequestTypeDef
+):
+    pass
+
+
 CreateGroupOutputTypeDef = TypedDict(
     "CreateGroupOutputTypeDef",
     {
@@ -77,6 +117,15 @@ CreateGroupOutputTypeDef = TypedDict(
     },
 )
 
+DeleteGroupInputRequestTypeDef = TypedDict(
+    "DeleteGroupInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+    },
+    total=False,
+)
+
 DeleteGroupOutputTypeDef = TypedDict(
     "DeleteGroupOutputTypeDef",
     {
@@ -95,6 +144,14 @@ FailedResourceTypeDef = TypedDict(
     total=False,
 )
 
+GetGroupConfigurationInputRequestTypeDef = TypedDict(
+    "GetGroupConfigurationInputRequestTypeDef",
+    {
+        "Group": str,
+    },
+    total=False,
+)
+
 GetGroupConfigurationOutputTypeDef = TypedDict(
     "GetGroupConfigurationOutputTypeDef",
     {
@@ -103,6 +160,15 @@ GetGroupConfigurationOutputTypeDef = TypedDict(
     },
 )
 
+GetGroupInputRequestTypeDef = TypedDict(
+    "GetGroupInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+    },
+    total=False,
+)
+
 GetGroupOutputTypeDef = TypedDict(
     "GetGroupOutputTypeDef",
     {
@@ -111,6 +177,15 @@ GetGroupOutputTypeDef = TypedDict(
     },
 )
 
+GetGroupQueryInputRequestTypeDef = TypedDict(
+    "GetGroupQueryInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+    },
+    total=False,
+)
+
 GetGroupQueryOutputTypeDef = TypedDict(
     "GetGroupQueryOutputTypeDef",
     {
@@ -119,6 +194,13 @@ GetGroupQueryOutputTypeDef = TypedDict(
     },
 )
 
+GetTagsInputRequestTypeDef = TypedDict(
+    "GetTagsInputRequestTypeDef",
+    {
+        "Arn": str,
+    },
+)
+
 GetTagsOutputTypeDef = TypedDict(
     "GetTagsOutputTypeDef",
     {
@@ -206,6 +288,14 @@ GroupQueryTypeDef = TypedDict(
     },
 )
 
+GroupResourcesInputRequestTypeDef = TypedDict(
+    "GroupResourcesInputRequestTypeDef",
+    {
+        "Group": str,
+        "ResourceArns": List[str],
+    },
+)
+
 GroupResourcesOutputTypeDef = TypedDict(
     "GroupResourcesOutputTypeDef",
     {
@@ -236,6 +326,18 @@ class GroupTypeDef(_RequiredGroupTypeDef, _OptionalGroupTypeDef):
     pass
 
 
+ListGroupResourcesInputRequestTypeDef = TypedDict(
+    "ListGroupResourcesInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+        "Filters": List["ResourceFilterTypeDef"],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListGroupResourcesItemTypeDef = TypedDict(
     "ListGroupResourcesItemTypeDef",
     {
@@ -256,6 +358,16 @@ ListGroupResourcesOutputTypeDef = TypedDict(
     },
 )
 
+ListGroupsInputRequestTypeDef = TypedDict(
+    "ListGroupsInputRequestTypeDef",
+    {
+        "Filters": List["GroupFilterTypeDef"],
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListGroupsOutputTypeDef = TypedDict(
     "ListGroupsOutputTypeDef",
     {
@@ -284,6 +396,15 @@ PendingResourceTypeDef = TypedDict(
     total=False,
 )
 
+PutGroupConfigurationInputRequestTypeDef = TypedDict(
+    "PutGroupConfigurationInputRequestTypeDef",
+    {
+        "Group": str,
+        "Configuration": List["GroupConfigurationItemTypeDef"],
+    },
+    total=False,
+)
+
 QueryErrorTypeDef = TypedDict(
     "QueryErrorTypeDef",
     {
@@ -337,6 +458,28 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+_RequiredSearchResourcesInputRequestTypeDef = TypedDict(
+    "_RequiredSearchResourcesInputRequestTypeDef",
+    {
+        "ResourceQuery": "ResourceQueryTypeDef",
+    },
+)
+_OptionalSearchResourcesInputRequestTypeDef = TypedDict(
+    "_OptionalSearchResourcesInputRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class SearchResourcesInputRequestTypeDef(
+    _RequiredSearchResourcesInputRequestTypeDef, _OptionalSearchResourcesInputRequestTypeDef
+):
+    pass
+
+
 SearchResourcesOutputTypeDef = TypedDict(
     "SearchResourcesOutputTypeDef",
     {
@@ -347,6 +490,14 @@ SearchResourcesOutputTypeDef = TypedDict(
     },
 )
 
+TagInputRequestTypeDef = TypedDict(
+    "TagInputRequestTypeDef",
+    {
+        "Arn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
 TagOutputTypeDef = TypedDict(
     "TagOutputTypeDef",
     {
@@ -356,6 +507,14 @@ TagOutputTypeDef = TypedDict(
     },
 )
 
+UngroupResourcesInputRequestTypeDef = TypedDict(
+    "UngroupResourcesInputRequestTypeDef",
+    {
+        "Group": str,
+        "ResourceArns": List[str],
+    },
+)
+
 UngroupResourcesOutputTypeDef = TypedDict(
     "UngroupResourcesOutputTypeDef",
     {
@@ -366,6 +525,14 @@ UngroupResourcesOutputTypeDef = TypedDict(
     },
 )
 
+UntagInputRequestTypeDef = TypedDict(
+    "UntagInputRequestTypeDef",
+    {
+        "Arn": str,
+        "Keys": List[str],
+    },
+)
+
 UntagOutputTypeDef = TypedDict(
     "UntagOutputTypeDef",
     {
@@ -375,6 +542,16 @@ UntagOutputTypeDef = TypedDict(
     },
 )
 
+UpdateGroupInputRequestTypeDef = TypedDict(
+    "UpdateGroupInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+        "Description": str,
+    },
+    total=False,
+)
+
 UpdateGroupOutputTypeDef = TypedDict(
     "UpdateGroupOutputTypeDef",
     {
@@ -383,6 +560,28 @@ UpdateGroupOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateGroupQueryInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateGroupQueryInputRequestTypeDef",
+    {
+        "ResourceQuery": "ResourceQueryTypeDef",
+    },
+)
+_OptionalUpdateGroupQueryInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateGroupQueryInputRequestTypeDef",
+    {
+        "GroupName": str,
+        "Group": str,
+    },
+    total=False,
+)
+
+
+class UpdateGroupQueryInputRequestTypeDef(
+    _RequiredUpdateGroupQueryInputRequestTypeDef, _OptionalUpdateGroupQueryInputRequestTypeDef
+):
+    pass
+
+
 UpdateGroupQueryOutputTypeDef = TypedDict(
     "UpdateGroupQueryOutputTypeDef",
     {
